Data documentation compiled by Great Expectations

### titanic

### default

Data Asset | Profiling Results | Expectation Suite | Validation Results
--- | --- | --- | ---
Titanic |  | BasicDatasetProfiler |

### random

### default

Data Asset | Profiling Results | Expectation Suite | Validation Results
--- | --- | --- | ---
f2 |  | BasicDatasetProfiler |
f1 |  | BasicDatasetProfiler |

Documentation autogenerated using Great Expectations.

This is a beta feature! Expect changes in API, behavior, and design.